@@ -1,4 +1,4 @@
-# $Id: Stream.pm,v 1.14 2005/06/29 04:05:44 rcaputo Exp $
+# $Id: Stream.pm 2220 2007-08-19 00:59:33Z rcaputo $
 
 package POE::Filter::Stream;
 
@@ -6,7 +6,7 @@ use strict;
 use POE::Filter;
 
 use vars qw($VERSION @ISA);
-$VERSION = do {my@r=(q$Revision: 1.14 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
+$VERSION = do {my($r)=(q$Revision: 2220 $=~/(\d+)/);sprintf"1.%04d",$r};
 @ISA = qw(POE::Filter);
 
 #------------------------------------------------------------------------------
@@ -18,6 +18,12 @@ sub new {
   $self;
 }
 
+sub clone {
+  my $self = shift;
+  my $buffer = '';
+  my $clone = bless \$buffer, ref $self;
+}
+
 #------------------------------------------------------------------------------
 # get() is inherited from POE::Filter.
 
@@ -92,3 +98,6 @@ Oh, probably some.
 Please see L<POE> for more information about authors and contributors.
 
 =cut
+
+# rocco // vim: ts=2 sw=2 expandtab
+# TODO - Redocument.
